---
title: alertmanager
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.alertmanager) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.alertmanager?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.alertmanager) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg?label=license)](https://gitea.rknet.org/ansible/xoxys.alertmanager/src/branch/main/LICENSE)

Setup Prometheus [Alertmanager](https://prometheus.io/docs/alerting/latest/alertmanager/) service.

<!--more-->

- [Default Variables](#default-variables)
  - [alertmanager_amtool_config_alertmanager_url](#alertmanager_amtool_config_alertmanager_url)
  - [alertmanager_amtool_config_output](#alertmanager_amtool_config_output)
  - [alertmanager_base_dir](#alertmanager_base_dir)
  - [alertmanager_cluster_bind_ip](#alertmanager_cluster_bind_ip)
  - [alertmanager_cluster_bind_port](#alertmanager_cluster_bind_port)
  - [alertmanager_config_dir](#alertmanager_config_dir)
  - [alertmanager_config_flags_extra](#alertmanager_config_flags_extra)
  - [alertmanager_data_dir](#alertmanager_data_dir)
  - [alertmanager_extra_groups](#alertmanager_extra_groups)
  - [alertmanager_group](#alertmanager_group)
  - [alertmanager_inhibit_rules](#alertmanager_inhibit_rules)
  - [alertmanager_log_level](#alertmanager_log_level)
  - [alertmanager_packages](#alertmanager_packages)
  - [alertmanager_read_only_dirs](#alertmanager_read_only_dirs)
  - [alertmanager_receivers](#alertmanager_receivers)
  - [alertmanager_resolve_timeout](#alertmanager_resolve_timeout)
  - [alertmanager_route_default_receiver](#alertmanager_route_default_receiver)
  - [alertmanager_route_group_by](#alertmanager_route_group_by)
  - [alertmanager_route_group_interval](#alertmanager_route_group_interval)
  - [alertmanager_route_group_wait](#alertmanager_route_group_wait)
  - [alertmanager_route_repeat_interval](#alertmanager_route_repeat_interval)
  - [alertmanager_route_routes](#alertmanager_route_routes)
  - [alertmanager_smtp_auth_password](#alertmanager_smtp_auth_password)
  - [alertmanager_smtp_auth_username](#alertmanager_smtp_auth_username)
  - [alertmanager_smtp_from](#alertmanager_smtp_from)
  - [alertmanager_smtp_host](#alertmanager_smtp_host)
  - [alertmanager_smtp_port](#alertmanager_smtp_port)
  - [alertmanager_smtp_require_tls](#alertmanager_smtp_require_tls)
  - [alertmanager_storage_retention](#alertmanager_storage_retention)
  - [alertmanager_template_files](#alertmanager_template_files)
  - [alertmanager_templates_dir](#alertmanager_templates_dir)
  - [alertmanager_user](#alertmanager_user)
  - [alertmanager_user_home](#alertmanager_user_home)
  - [alertmanager_version](#alertmanager_version)
  - [alertmanager_web_basic_auth_users](#alertmanager_web_basic_auth_users)
  - [alertmanager_web_bind_ip](#alertmanager_web_bind_ip)
  - [alertmanager_web_bind_port](#alertmanager_web_bind_port)
  - [alertmanager_web_external_url](#alertmanager_web_external_url)
  - [alertmanager_web_http_server](#alertmanager_web_http_server)
  - [alertmanager_web_tls_cert_path](#alertmanager_web_tls_cert_path)
  - [alertmanager_web_tls_cert_source](#alertmanager_web_tls_cert_source)
  - [alertmanager_web_tls_enabled](#alertmanager_web_tls_enabled)
  - [alertmanager_web_tls_key_path](#alertmanager_web_tls_key_path)
  - [alertmanager_web_tls_key_source](#alertmanager_web_tls_key_source)
- [Discovered Tags](#discovered-tags)
- [Dependencies](#dependencies)

---

## Default Variables

### alertmanager_amtool_config_alertmanager_url

Location (URL) of the alertmanager.

#### Default value

```YAML
alertmanager_amtool_config_alertmanager_url: '{{ alertmanager_web_external_url }}'
```

### alertmanager_amtool_config_output

Extended output of `amtool` commands, use '' for less verbosity.

#### Default value

```YAML
alertmanager_amtool_config_output: extended
```

### alertmanager_base_dir

#### Default value

```YAML
alertmanager_base_dir: /opt/alertmanager
```

### alertmanager_cluster_bind_ip

#### Default value

```YAML
alertmanager_cluster_bind_ip: 127.0.0.1
```

### alertmanager_cluster_bind_port

#### Default value

```YAML
alertmanager_cluster_bind_port: 61002
```

### alertmanager_config_dir

#### Default value

```YAML
alertmanager_config_dir: '{{ alertmanager_base_dir }}/conf'
```

### alertmanager_config_flags_extra

#### Default value

```YAML
alertmanager_config_flags_extra: []
```

#### Example usage

```YAML
alertmanager_config_flags_extra:
  - name: data.retention
    value: 10
```

### alertmanager_data_dir

#### Default value

```YAML
alertmanager_data_dir: '{{ alertmanager_base_dir }}/data'
```

### alertmanager_extra_groups

#### Default value

```YAML
alertmanager_extra_groups: []
```

### alertmanager_group

#### Default value

```YAML
alertmanager_group: '{{ alertmanager_user }}'
```

### alertmanager_inhibit_rules

#### Default value

```YAML
alertmanager_inhibit_rules: []
```

### alertmanager_log_level

#### Default value

```YAML
alertmanager_log_level: error
```

### alertmanager_packages

#### Default value

```YAML
alertmanager_packages:
  - tar
```

### alertmanager_read_only_dirs

#### Default value

```YAML
alertmanager_read_only_dirs: []
```

### alertmanager_receivers

#### Default value

```YAML
alertmanager_receivers: []
```

#### Example usage

```YAML
alertmanager_receivers:
  - name: slack
    slack_configs:
      - send_resolved: true
        channel: '#alerts'
```

### alertmanager_resolve_timeout

#### Default value

```YAML
alertmanager_resolve_timeout: 3m
```

### alertmanager_route_default_receiver

#### Example usage

```YAML
alertmanager_route_default_receiver: slack
```

### alertmanager_route_group_by

#### Default value

```YAML
alertmanager_route_group_by:
  - alertname
  - service
```

### alertmanager_route_group_interval

#### Default value

```YAML
alertmanager_route_group_interval: 5m
```

### alertmanager_route_group_wait

#### Default value

```YAML
alertmanager_route_group_wait: 30s
```

### alertmanager_route_repeat_interval

#### Default value

```YAML
alertmanager_route_repeat_interval: 3h
```

### alertmanager_route_routes

#### Default value

```YAML
alertmanager_route_routes: []
```

### alertmanager_smtp_auth_password

#### Default value

```YAML
alertmanager_smtp_auth_password: secure
```

### alertmanager_smtp_auth_username

#### Default value

```YAML
alertmanager_smtp_auth_username: mail
```

### alertmanager_smtp_from

#### Default value

```YAML
alertmanager_smtp_from: alerts@example.com
```

### alertmanager_smtp_host

Mail server used to send alerts. Need to be defined to enable Mail notifications.

#### Default value

```YAML
alertmanager_smtp_host: _unset_
```

### alertmanager_smtp_port

#### Default value

```YAML
alertmanager_smtp_port: 587
```

### alertmanager_smtp_require_tls

#### Default value

```YAML
alertmanager_smtp_require_tls: 'True'
```

### alertmanager_storage_retention

#### Default value

```YAML
alertmanager_storage_retention: 120h
```

### alertmanager_template_files

#### Default value

```YAML
alertmanager_template_files:
  - alertmanager/templates/*.tmpl
```

### alertmanager_templates_dir

#### Default value

```YAML
alertmanager_templates_dir: '{{ alertmanager_config_dir }}/templates'
```

### alertmanager_user

#### Default value

```YAML
alertmanager_user: alertmanager_adm
```

### alertmanager_user_home

#### Default value

```YAML
alertmanager_user_home: /home/{{ alertmanager_user }}
```

### alertmanager_version

#### Default value

```YAML
alertmanager_version: 0.22.0
```

### alertmanager_web_basic_auth_users

See official [documentation](https://github.com/prometheus/exporter-toolkit/blob/master/docs/web-configuration.md).

#### Default value

```YAML
alertmanager_web_basic_auth_users: _unset_
```

### alertmanager_web_bind_ip

#### Default value

```YAML
alertmanager_web_bind_ip: 127.0.0.1
```

### alertmanager_web_bind_port

#### Default value

```YAML
alertmanager_web_bind_port: 61001
```

### alertmanager_web_external_url

#### Default value

```YAML
alertmanager_web_external_url: http://localhost:61001/
```

### alertmanager_web_http_server

See official [documentation](https://github.com/prometheus/exporter-toolkit/blob/master/docs/web-configuration.md).

#### Default value

```YAML
alertmanager_web_http_server: _unset_
```

### alertmanager_web_tls_cert_path

#### Default value

```YAML
alertmanager_web_tls_cert_path: '{{ alertmanager_base_dir }}/tls/certs/mycert.pem'
```

### alertmanager_web_tls_cert_source

#### Default value

```YAML
alertmanager_web_tls_cert_source: mycert.pem
```

### alertmanager_web_tls_enabled

#### Default value

```YAML
alertmanager_web_tls_enabled: false
```

### alertmanager_web_tls_key_path

#### Default value

```YAML
alertmanager_web_tls_key_path: '{{ alertmanager_base_dir }}/tls/private/mykey.pem'
```

### alertmanager_web_tls_key_source

#### Default value

```YAML
alertmanager_web_tls_key_source: mykey.pem
```

## Discovered Tags

tls_renewal
: &nbsp;


## Dependencies

None.
